<?php

declare(strict_types=1);

namespace Drupal\crm\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBundleBase;
use Drupal\crm\CrmContactDetailTypeInterface;

/**
 * Defines the CRM Contact Detail type configuration entity.
 *
 * @ConfigEntityType(
 *   id = "crm_contact_detail_type",
 *   label = @Translation("CRM Contact Detail type"),
 *   label_collection = @Translation("CRM Contact Detail types"),
 *   label_singular = @Translation("crm contact detail type"),
 *   label_plural = @Translation("crm contact details types"),
 *   label_count = @PluralTranslation(
 *     singular = "@count crm contact details type",
 *     plural = "@count crm contact details types",
 *   ),
 *   handlers = {
 *     "access" = "Drupal\crm\ContactDetailTypeAccessControlHandler",
 *     "form" = {
 *       "add" = "Drupal\crm\Form\ContactDetailTypeForm",
 *       "edit" = "Drupal\crm\Form\ContactDetailTypeForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm",
 *     },
 *     "list_builder" = "Drupal\crm\ContactDetailTypeListBuilder",
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\AdminHtmlRouteProvider",
 *     },
 *   },
 *   admin_permission = "administer crm contact detail types",
 *   bundle_of = "crm_contact_detail",
 *   config_prefix = "crm_contact_detail_type",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid",
 *   },
 *   links = {
 *     "add-form" = "/admin/structure/crm/contact-detail-types/add",
 *     "edit-form" = "/admin/structure/crm/contact-detail-types/manage/{crm_contact_detail_type}",
 *     "delete-form" = "/admin/structure/crm/contact-detail-types/manage/{crm_contact_detail_type}/delete",
 *     "collection" = "/admin/structure/crm/contact-detail-types",
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "description",
 *     "uuid",
 *     "locked",
 *   },
 * )
 */
final class ContactDetailType extends ConfigEntityBundleBase implements CrmContactDetailTypeInterface {

  /**
   * The machine name of this crm contact detail type.
   */
  protected string $id;

  /**
   * The human-readable name of the crm contact detail type.
   */
  protected string $label;

  /**
   * The description of the crm contact detail type.
   *
   * @var string|null
   */
  protected ?string $description;

  /**
   * Whether the Contact Detail Type is locked.
   */
  protected bool $locked = FALSE;

  /**
   * Is the contact type locked?
   */
  public function isLocked(): bool {
    return $this->locked;
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return $this->description ?? '';
  }

  /**
   * {@inheritdoc}
   */
  public function setDescription($description) {
    $this->description = $description;

    return $this;
  }

}
