<?php

namespace Drupal\crm\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\crm\CrmDetailTypeInterface;

/**
 * Defines the detail type entity type.
 *
 * @ConfigEntityType(
 *   id = "crm_detail_type",
 *   label = @Translation("Detail Type"),
 *   label_collection = @Translation("Detail Types"),
 *   label_singular = @Translation("detail type"),
 *   label_plural = @Translation("detail types"),
 *   label_count = @PluralTranslation(
 *     singular = "@count detail type",
 *     plural = "@count detail types",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\crm\DetailTypeListBuilder",
 *     "form" = {
 *       "add" = "Drupal\crm\Form\DetailTypeForm",
 *       "edit" = "Drupal\crm\Form\DetailTypeForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm"
 *     }
 *   },
 *   config_prefix = "crm_detail_type",
 *   admin_permission = "administer crm",
 *   links = {
 *     "collection" = "/admin/structure/crm/detail-type",
 *     "add-form" = "/admin/structure/crm/detail-type/add",
 *     "edit-form" = "/admin/structure/crm/detail-type/{crm_detail_type}",
 *     "delete-form" = "/admin/structure/crm/detail-type/{crm_detail_type}/delete"
 *   },
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "description",
 *     "bundles",
 *     "negate"
 *   }
 * )
 */
class DetailType extends ConfigEntityBase implements CrmDetailTypeInterface {

  /**
   * The detail type id.
   *
   * @var string
   */
  protected $id;

  /**
   * The detail type label.
   *
   * @var string
   */
  protected $label;

  /**
   * The detail type status.
   *
   * @var bool
   */
  protected $status;

  /**
   * The crm_detail_type description.
   *
   * @var string
   */
  protected $description;

  /**
   * The bundles associated with this detail type.
   *
   * @var array
   */
  protected $bundles;

  /**
   * The negate condition for this detail type.
   *
   * @var bool
   */
  protected $negate;

}
