<?php

declare(strict_types=1);

namespace Drupal\Tests\crm\Unit\Form;

use Drupal\Tests\UnitTestCase;
use Drupal\crm\Form\RelationshipTypeForm;
use Symfony\Component\DependencyInjection\ContainerBuilder;

/**
 * Relationship type form test.
 *
 * @group crm
 * @coversDefaultClass \Drupal\crm\Form\RelationshipTypeForm
 * @uses \Drupal\crm\Form\RelationshipTypeForm
 */
class RelationshipTypeFormTest extends UnitTestCase {

  /**
   * The form.
   *
   * @var \Drupal\visitors\Form\RelationshipTypeForm
   */
  protected $form;

  /**
   * The messenger.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface|\PHPUnit\Framework\MockObject\MockObject
   */
  protected $messenger;


  /**
   * The entity type bundle info.
   *
   * @var \Drupal\Core\Entity\EntityTypeBundleInfoInterface|\PHPUnit\Framework\MockObject\MockObject
   */
  protected $entityTypeBundleInfo;

  /**
   * The entity.
   *
   * @var \Drupal\crm\Entity\RelationshipType|\PHPUnit\Framework\MockObject\MockObject
   */
  protected $entity;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $container = new ContainerBuilder();

    $string_translation = $this->getStringTranslationStub();
    $container->set('string_translation', $string_translation);

    $this->entityTypeBundleInfo = $this->createMock('Drupal\Core\Entity\EntityTypeBundleInfoInterface');
    $container->set('entity_type.bundle.info', $this->entityTypeBundleInfo);

    \Drupal::setContainer($container);

    $this->form = RelationshipTypeForm::create($container);

    $this->entity = $this->createMock('Drupal\crm\Entity\RelationshipType');
    $this->form->setEntity($this->entity);

  }

  /**
   * Tests the create method.
   *
   * @covers ::create
   */
  public function testCreate() {
    $container = \Drupal::getContainer();
    $form = RelationshipTypeForm::create($container);

    $this->assertInstanceOf(RelationshipTypeForm::class, $form);
  }

  /**
   * Test the constructor.
   *
   * @covers ::__construct
   */
  public function testConstructor() {
    $form = new RelationshipTypeForm(
      $this->entityTypeBundleInfo,
    );
    $this->assertInstanceOf(RelationshipTypeForm::class, $form);
  }

  /**
   * Test the form id.
   *
   * @covers ::getFormId
   */
  public function testGetFormId() {
    $entity_type = $this->createMock('Drupal\Core\Entity\EntityTypeInterface');
    $entity_type->expects($this->once())
      ->method('hasKey')
      ->with('bundle')
      ->willReturn(FALSE);
    $this->entity->expects($this->once())
      ->method('getEntityTypeId')
      ->willReturn('crm_relationship_type');
    $this->entity->expects($this->once())
      ->method('getEntityType')
      ->willReturn($entity_type);

    $this->form->setOperation('edit');

    $this->assertEquals('crm_relationship_type_edit_form', $this->form->getFormId());
  }

  /**
   * Test the form build.
   *
   * @covers ::form
   */
  public function testForm() {
    $entity_type = $this->createMock('Drupal\Core\Entity\EntityTypeInterface');
    $entity_type->expects($this->once())
      ->method('getKey')
      ->with('id')
      ->willReturn('id');

    $this->entity->expects($this->once())
      ->method('getEntityType')
      ->willReturn($entity_type);

    $this->entityTypeBundleInfo->expects($this->exactly(2))
      ->method('getBundleInfo')
      ->with('crm_contact')
      ->willReturn([
        'person' => ['label' => 'Person'],
        'household' => ['label' => 'Household'],
        'organization' => ['label' => 'Organization'],
      ]);

    $form_state = $this->createMock('Drupal\Core\Form\FormStateInterface');
    $form = $this->form->form([], $form_state);
    $this->assertIsArray($form);
    $this->assertCount(10, $form);

  }

}
